@@ -359,7 +359,7 @@ validateReturnAuth(BYTE *secret, BYTE *hash, TPM_AUTH *auth)
 	memcpy(digest, &auth->HMAC, 20);
 	HMAC_Auth(secret, hash, auth);
 
-	return ((TSS_BOOL) memcmp(digest, &auth->HMAC, 20) != 0);
+	return ((TSS_BOOL) (memcmp(digest, &auth->HMAC, 20) != 0));
 }
 
 void
@@ -1211,7 +1211,7 @@ Transport_TerminateHandle(TSS_HCONTEXT tspContext, /* in */
 			  TCS_AUTHHANDLE handle)   /* in */
 {
 	TSS_RESULT result;
-	TCS_HANDLE handlesLen = 0, *handles;
+	TCS_HANDLE handlesLen = 0, *handles, *handles_track;
 
 	/* Call ExecuteTransport */
 	handlesLen = 1;
@@ -1221,10 +1221,18 @@ Transport_TerminateHandle(TSS_HCONTEXT tspContext, /* in */
 	}
 
 	*handles = handle;
+	handles_track = handles;
 
+	// Since the call tree of this function can possibly alloc memory
+	// (check RPC_ExecuteTransport_TP function), its better to keep track of
+	// the handle.
 	result = obj_context_transport_execute(tspContext, TPM_ORD_Terminate_Handle, 0, NULL,
 					       NULL, &handlesLen, &handles, NULL, NULL, NULL, NULL);
 
+	if (handles != handles_track)
+		free(handles);
+	free(handles_track);
+
 	return result;
 }
 #endif
